@@ -1,20 +1,22 @@
-import os, sys, getopt
-
+import os, sys
 import re
 import json
-import requests
+import time
+import getopt
 import random
 import hashlib
+import requests
 
 from unittest import result
 from collections import namedtuple
-from termcolor import cprint
+from termcolor import cprint, colored
 from urllib.parse import quote
 
 appid = '20220325001140552'
 secretKey = 'LiIWn_rNJrbLErVu6sGT'
 
-def get_myurl(word,fromLang='auto',toLang = 'zh'):   
+def get_myurl(words,fromLang='auto',toLang = 'zh'): 
+    for word in words:  
         salt = random.randint(32768, 65536)
         sign = appid + word + str(salt) + secretKey
         myMd5 = hashlib.md5()
@@ -27,7 +29,9 @@ def get_translate_word(url):
         response = requests.get('http://api.fanyi.baidu.com' + url)
         result=response.json()
         for item in result['trans_result']:
-            cprint (item['dst'], "green")
+            text_1 = colored(item['src']+':', "red")
+            text_2 = colored(item['dst'], "green")
+            print(text_1+text_2)
     except Exception as e:
         print(e)
 
@@ -40,8 +44,11 @@ def main():
 
     match = re.findall(r'[\w.]+', " ".join(args).lower())
     word = " ".join(match)
-    for u in get_myurl(word):
+    words = word.split( )
+    for u in get_myurl(words):
         get_translate_word(u)
+        time.sleep(1)
 
 if __name__ == '__main__':
     main()
+
